@@ -13,6 +13,7 @@ import os
 
 COLUMN_GAP = 4
 DEFAULT_ENDPOINT = 'http://127.0.0.1:8053'
+VERSION = 'v1.2.0'
 
 config = {}
 console = Console()
@@ -92,7 +93,7 @@ def ls(domain):
     console.print(f"[yellow bold]{''.join([h.ljust(column_widths[h], ' ').upper() for h in headers])}[/]")
     for i in range(len(columns['domain'])):
         row = ''.join([columns[h][i].ljust(column_widths[h], ' ') for h in headers])
-        console.print(f'[white]{row}[/]')
+        print(row)
 
 
 @cli.command()
@@ -139,3 +140,17 @@ def delete(domain, record_id):
         return
 
     console.print(f"[green bold]OK[/]")
+
+
+@cli.command()
+def version():
+    print(f'Client: {VERSION}')
+
+    server_version = 'UNKNOWN'
+    try:
+        res = requests.get(f"{config['api_prefix']}/version")
+        assert res.status_code == 200
+        server_version = res.text
+    except:
+        pass
+    print(f'Server: {server_version}')
